@@ -11,7 +11,7 @@ def try_type(s):
         return "\"%s\"" % pymysql.converters.escape_string(s)
 
 
-def format_condition_into_mysql(s: dict, sp="and", prefix="WHERE"):
+def format_condition_into_mysql(s: dict, sp="and", prefix="WHERE BINARY"):
     """
     格式化MySQL子句
     name: MySQL子句的前缀（也就是转换后的任意前缀）
